<%--
//-----------------------------------------------------------------------------
// Copyright (c) 2011-2012 XEROX Corporation.  All rights reserved
//-----------------------------------------------------------------------------
// Revision History:
// -----------------
// AR Number      Author   Date         Change Description
// ---------      ------   ----         ------------------
//
// CQGbl00349040  bvu      01/04/2012   Created       
//-----------------------------------------------------------------------------
--%>

<%--
  Main page of Xerox ePO extension showing all Xerox MFP present on
  the network and their information
--%>

<%@ taglib uri="http://www.mcafee.com/orion" prefix="orion" %>
<%@ taglib prefix="c" uri="http://java.sun.com/jstl/core_rt" %>

<orion:core>

  <orion:corehead>

    <script type="text/javascript">
  
    // Carries out the provisioning operation after checking
    // the data provided by the McAfee table tag
    function doProvision(serverResponse) {

      // This should never happen
      if (serverResponse== "failedDueToSystem") {

        OrionCore.setDialogBoxTitle('<orion:message key="XeroxMFP.provision.result.title" escape="Javascript"/>');
        OrionCore.showDialogBox( true, '<orion:message key="XeroxMFP.provision.result.no.data.msg" escape="Javascript"/>', OrionCore.DIALOG_OK );
      }
      else if (serverResponse== "adminCredentialsUsed") {

        OrionCore.setDialogBoxTitle('<orion:message key="XeroxMFP.provision.result.title" escape="Javascript"/>');
        OrionCore.showDialogBox( true, '<orion:message key="XeroxMFP.provision.result.adminCredentials.notAllowed" escape="Javascript"/>', OrionCore.DIALOG_OK );
      }
      else if (serverResponse== "preCannedUserDeleted") {

        OrionCore.setDialogBoxTitle('<orion:message key="XeroxMFP.provision.result.title" escape="Javascript"/>');
        OrionCore.showDialogBox( true, '<orion:message key="XeroxMFP.provision.result.preCannedUserDeleted" escape="Javascript"/>', OrionCore.DIALOG_OK );
      }
      
      // All is well.  Now provision the machines
      else {
        // Put up the please wait
        OrionCore.showPleaseWait(true);
        OrionCore.doAsyncAction('/XeroxMFP/provision.do', null, provisionStatus);
      }

    
    }

    // Processes the status of the provisioning operation
    function provisionStatus(serverResponse) {
    
      OrionCore.showPleaseWait(false);
      OrionCore.setDialogBoxTitle('<orion:message key="XeroxMFP.provision.result.title" escape="Javascript"/>');
      OrionCore.showDialogBox( true, serverResponse, OrionCore.DIALOG_OK, 350, 710);

      OrionCore.dialogBoxOkHandler = refreshDeviceTableView;

    }

    // Processes the navigation menu selection
    function nodeSelected (node)
    {
      var selectedKey = OrionTree.getNodeKey(node);
      if ("XeroxMFP.deviceTableTitle" != OrionTree.getNodeKey(node)) {
        var params = [];

        params.push("menuItemKey");
        params.push(selectedKey); 

        OrionCore.doAction("/XeroxMFP/activateMenuItem.do", params);  
      }

    }



    // Refresh the Xerox MFP table view
    function refreshDeviceTableView()
    {
      var deviceTable = MFSTable.get("xeroxDeviceTable");
      
      deviceTable.refresh();
            
    }
  
    function getErrors() {
      OrionCore.doAsyncAction('/XeroxMFP/getErrors.do', null, checkForErrors);
    }
  
    function handleOnloadEvent(){
      // Set the initial state of the navigation menu
      OrionTree.setSelectedNode(OrionTree.getNodeByKey("menu", "XeroxMFP.deviceTableTitle"));
    
      var deviceTable = MFSTable.get("xeroxDeviceTable");
      deviceTable.setTableReloadHandler(getErrors);
    }
  
    // Check and notify user if there are errors
    function checkForErrors(errors) {
            
      // Format of the data: errorCode|descriptionKey|errorCode|descriptionKey... 
      if (errors != null && errors != "") {
      
        var errorsArray = errors.split("|");
       
        // Now format the data
        var formattedData = new Array();
        
        // Build top part of the table
        var tableTop = new Array();
        tableTop[0] = new String("<table id=\"errorTable\" width=\"100%\" align=\"center\" cellspacing=\"0\"><tr><td class=\"orionSummaryHeader\" width=\"20%\">");
        tableTop[1] = new String('<orion:message key="XeroxMFP.errorCode" escape="Javascript"/>');
        tableTop[2] = new String("</td><td class=\"orionSummaryHeader\" width=\"80%\">");
        tableTop[3] = new String('<orion:message key="XeroxMFP.description" escape="Javascript"/>');
        tableTop[4] = new String("</td></tr>");
  
        // Flatten the array and remove the ","
        formattedData[0] = tableTop.toString().replace(/,/g,"");
        
        // Build the data part 
        var tableBody = new Array();
          
          j = 0;
          for (i = 0; i < errorsArray.length; i = i+2) {
           
            tableBody[j] = new String("<tr><td class=\"orionSummaryColumn\" width=\"20%\"><span style=\"color:red\">");
            tableBody[j+1] = errorsArray[i];
            tableBody[j+2] = new String("</span></td><td class=\"orionSummaryColumn\" width=\"80%\">");
            tableBody[j+3] = errorsArray[i+1];
            tableBody[j+4] = new String("</td></tr>");
            j = j + 5;
          } 
          
          // Flatten the array and remove the ","
          formattedData[1] = tableBody.toString().replace(/,/g,"");
              
        // Close the table
        formattedData[3] = new String("</table>");
        
        // Now Display the formatted data
        OrionCore.setDialogBoxTitle('<orion:message key="XeroxMFP.errors.title" escape="Javascript"/>');
        OrionCore.showDialogBox( true, formattedData.toString().replace(/,/g,""), OrionCore.DIALOG_OK );     
        OrionCore.dialogBoxOkHandler = cleanUpErrors;
       
      }
      
    }
    
    function cleanUpErrors(){
      OrionCore.doAsyncAction('/XeroxMFP/cleanUpErrors.do', null, null);
    }
  
  
  
  </script>

  </orion:corehead>


  <orion:corebody onload="handleOnloadEvent()">

    <orion:navigation tabId="XeroxMFP.tab"/>
    <orion:content>

      <orion:hbox>
        <!-- Navigation menu area -->
        <orion:vbox width="200" id="opList">

          <orion:message key="XeroxMFP.menu.title" escape="none" var="menuTitle" /> 
          <orion:titlebar id="listTitle" text="${menuTitle}" />

            <orion:tree id="menu" treeDataAttr="optionLister" 
                        showRootNode="false" selectable="true" />

            <script type="text/javascript">
                    OrionTree.setSelectHandler(nodeSelected);
            </script>

        </orion:vbox>


        <!-- create a divider -->
        <orion:vdivider id="myDivider" resizeTarget="opList" />


	<!-- Main content area -->
        <orion:vbox>

          <orion:message key="XeroxMFP.deviceTableTitle" escape="none" var="tabletile" />
          <orion:tabletitle id="deviceTableTitle" tableId="xeroxDeviceTable" text="${tabletile}"/>

          <orion:table2 datasourceAttr="xeroxDeviceDataSource"
                         id="xeroxDeviceTable"
                         cellRendererAttr="${cellRendererAttr}"
                         showCheckboxColumn="true"
			 sortColumn="deviceName"
			 sortOrder="0"
			 properties="deviceName,status,ip,deviceModel,serial"
                         registeredTypeUID="xeroxDeviceUID"
                         enableDrilldown="true"
			 refresh="true" 
			 showTitleBar="false"
			 allowAction="true">
          </orion:table2> 
	    
	</orion:vbox>

      </orion:hbox>

   </orion:content>
 </orion:corebody>
</orion:core>
