<%--
//-----------------------------------------------------------------------------
// Copyright (c) 2011-2012 XEROX Corporation.  All rights reserved
//-----------------------------------------------------------------------------
// Revision History:
// -----------------
// AR Number      Author   Date         Change Description
// ---------      ------   ----         ------------------
//
// CQGbl00349040  bvu      01/04/2012   Created       
//-----------------------------------------------------------------------------
--%>

<%-- 
  The view showing the tabs on the Software Update page
  This is part of the McAfee tab configuration.
--%>

<%@ taglib uri="http://www.mcafee.com/orion" prefix="orion" %>
<%@ taglib prefix="c" uri="http://java.sun.com/jstl/core_rt" %>

<orion:core>

  <orion:corehead>

    <script type="text/javascript">

      // Initializes the page
      function initialize() {

        if ($("firmwareSelect") != null) { 
	  $("firmwareSelect").options[0].selected = true;
        }

        OrionForm.rescan();
        OrionForm.setStateChangeHandler(formHandler);
      }

      // Handles the state of the form
      function formHandler(isDirty, isValid )
      {
        // Only enable the ok button when the form is valid and the user has made changes.
        OrionCore.setEnabledById("ok", isValid && isDirty);
      }

      // Validates the file type
      function validateFileType(value) {   

        //checking for file types
        var fileName = value.toLowerCase();
        var idx = fileName.lastIndexOf(".");
        var sfx = fileName.substring(idx + 1);

        return (sfx == "zip") && (OrionValidate.isValidFilePath(value));
      }

      // Carries out update software operation
      function updateSoftware()
      {
        OrionCore.showPleaseWait(true);
        OrionCore.doAsyncFormAction('/XeroxMFP/updateSoftware.do', null, formatUpdateStatus);
      }

      // Format the software update result
      function formatUpdateStatus(message) {
           
        // Separate the two result sets
        var results = message.split(",");
        
        if (results[1] != null) {
                
          // Split the data 
          var successful = results[0].split("|");
          var failed = results[1].split("|");
          var unknown = results[2].split("|");
        
 
          // Now format the data
          var formattedResults = new Array();
        
          // Build top part of the table
          var tableTop = new Array();
          tableTop[0] = new String("<table id=\"selectedDeviceTable\" width=\"100%\" align=\"center\" cellspacing=\"0\"><tr><td class=\"orionSummaryHeader\" width=\"40%\">");
          tableTop[1] = new String('<orion:message key="XeroxMFP.deviceName" escape="Javascript"/>');
          tableTop[2] = new String("</td><td class=\"orionSummaryHeader\" width=\"40%\">");
          tableTop[3] = new String('<orion:message key="XeroxMFP.ip" escape="Javascript"/>');
          tableTop[4] = new String("</td><td class=\"orionSummaryHeader\" width=\"20%\">");
          tableTop[5] = new String('<orion:message key="XeroxMFP.systemSoftwareUpdate.status" escape="Javascript"/>');
          tableTop[6] = new String("</td></tr>");
  
          formattedResults[0] = tableTop.toString().replace(/,/g,""); 
        
          formattedResults[1] = formatData(successful, "successful");
          formattedResults[2] = formatData(failed, "failed");
          formattedResults[3] = formatData(unknown, "unknown");             

          // Close the table
          formattedResults[4] = new String("</table>");
        
          displayUpdateStatus(formattedResults.toString().replace(/,/g,""));
        
        }
        else {
          displayUpdateStatus(message);
        }
      
      }
      
      
      function formatData(resultData, type){

        if (resultData[0] != "empty") {
        
          var table = new Array();
          
          j = 0;
          for (i = 0; i < resultData.length; i = i+2) {
           
            table[j] = new String("<tr><td class=\"orionSummaryColumn\" width=\"40%\">");
            table[j+1] = resultData[i];
            table[j+2] = new String("</td><td class=\"orionSummaryColumn\" width=\"40%\">");
            table[j+3] = resultData[i+1];
            
            
            if (type == "successful") {
              table[j+4] = new String("</td><td class=\"orionSummaryColumn\" width=\"20%\"><span style=\"color:black\">");
              table[j+5] = new String('<orion:message key="XeroxMFP.successful" escape="Javascript"/>');
            }
            else if (type == "failed") {
              table[j+4] = new String("</td><td class=\"orionSummaryColumn\" width=\"20%\"><span style=\"color:red\">");
              table[j+5] = new String('<orion:message key="XeroxMFP.failed" escape="Javascript"/>');
            }
            else if (type == "unknown") {
              table[j+4] = new String("</td><td class=\"orionSummaryColumn\" width=\"20%\"><span style=\"color:gray\">");
              table[j+5] = new String('<orion:message key="XeroxMFP.unknown" escape="Javascript"/>');
            }
            
            table[j+6] = new String("</span></td></tr>");
            j = j + 7;
          } 
          
          return table.toString().replace(/,/g,"");
        
        }
           
      }
      

      // Handle the result of the Update Software operation 
      function displayUpdateStatus(message) {

        OrionCore.showPleaseWait(false);

        OrionCore.setDialogBoxTitle('<orion:message key="XeroxMFP.systemSoftwareUpdate.result" escape="Javascript"/>');
        OrionCore.showDialogBox( true, message, OrionCore.DIALOG_OK, 350, 750);
        OrionCore.dialogBoxOkHandler = backToExtensionHome;
      }

      // Goes back to the main view of the Xerox extension
      function backToExtensionHome() {
        OrionCore.doAction("/XeroxMFP/backToExtensionHome.do", null);
      }

      // Updates the software of a MFP using the previously uploaded firmware on the server
      function updateFromServer() {
        var params = [];
        params.push("selectedFileName");
        params.push($("firmwareSelect").value);

        OrionCore.showPleaseWait(true);
        OrionCore.doAsyncAction('/XeroxMFP/updateSoftwareFromServer.do', params, displayUpdateStatus);
      }

      // Removes previously uploaded firmware from server
      function removeFromServer() {

        var selectBox = $("firmwareSelect");
        var selectedValues;

        var params = [];

        // Concatenate the file names
        for (var i = 0; i < selectBox.options.length; i++) {
          if (selectBox.options[i].selected) {

	    if(typeof(selectedValues) === 'undefined') {
              selectedValues = selectBox.options[i].value; 
	    }
	    else {
              selectedValues = selectedValues + "," + selectBox.options[i].value; 
	    }
          }
        }

        params.push("selectedFileNames");
        params.push(selectedValues);

        OrionCore.showPleaseWait(true);
        OrionCore.doAsyncAction('/XeroxMFP/removeSoftwareFromServer.do', params, removeSoftwareStatus);
      }

      // Handles the status of deleting the firmware from server
      function removeSoftwareStatus(message) {

        OrionCore.showPleaseWait(false);

        OrionCore.setDialogBoxTitle('<orion:message key="XeroxMFP.provision.result" escape="Javascript"/>');
        OrionCore.showDialogBox( true, message, OrionCore.DIALOG_OK, 300, 500);
        OrionCore.dialogBoxOkHandler = backToExtensionHome;
     }


    </script>
  
  </orion:corehead>

  <orion:corebody name="main" enctype="multipart/form-data" method="POST" onload="initialize()">

    <orion:navigation tabId="XeroxMFP.tab"/>
    <orion:content>

      <orion:vbox>
        <orion:tabstrip id="updateSoftwareTabStrip" tabStripInfo="${tabInfo}"/>
      </orion:vbox>

    </orion:content>
  </orion:corebody>
</orion:core>

